@@ -21,10 +21,10 @@
 #define IMPORTAKREGATORJOB_H
 
 #include "abstractimportexportjob.h"
-
+#include "pimsettingexportercore_private_export.h"
 class ArchiveStorage;
 
-class ImportAkregatorJob : public AbstractImportExportJob
+class PIMSETTINGEXPORTER_TESTS_EXPORT ImportAkregatorJob : public AbstractImportExportJob
 {
     Q_OBJECT
 public:
